"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var graphql_codegen_core_1 = require("graphql-codegen-core");
var fs = require("fs");
var path = require("path");
var document_finder_1 = require("../../utils/document-finder");
exports.loadFileContent = function (filePath) {
    if (fs.existsSync(filePath)) {
        var fileContent = fs.readFileSync(filePath, 'utf8');
        var fileExt = path.extname(filePath);
        if (fileExt === '.graphql' || fileExt === '.gql') {
            return graphql_codegen_core_1.parse(new graphql_codegen_core_1.Source(fileContent, filePath));
        }
        var foundDoc = document_finder_1.extractDocumentStringFromCodeFile(fileContent);
        if (foundDoc) {
            return graphql_codegen_core_1.parse(new graphql_codegen_core_1.Source(foundDoc, filePath));
        }
        else {
            return null;
        }
    }
    else {
        throw new Error("Document file " + filePath + " does not exists!");
    }
};
var effectiveRules = graphql_1.specifiedRules.filter(function (f) { return f.name !== 'NoUnusedFragments'; });
exports.loadDocumentsSources = function (schema, filePaths) {
    var loadResults = filePaths
        .map(function (filePath) { return ({ filePath: filePath, content: exports.loadFileContent(filePath) }); })
        .filter(function (result) { return result.content; });
    var errors = loadResults
        .map(function (result) { return ({
        filePath: result.filePath,
        errors: graphql_1.validate(schema, result.content, effectiveRules).filter(function (e) { return e.message.indexOf('Unknown fragment') === -1; })
    }); })
        .filter(function (r) { return r.errors.length > 0; });
    return errors.length > 0 ? errors : graphql_codegen_core_1.concatAST(loadResults.map(function (r) { return r.content; }));
};
//# sourceMappingURL=document-loader.js.map